@@ -1,13 +1,8 @@
-/******************************************************************************
-  This file is part of PyTango (http://pytango.rtfd.io)
-
-  Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-  Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-
-  Distributed under the terms of the GNU Lesser General Public License,
-  either version 3 of the License, or (at your option) any later version.
-  See LICENSE.txt for more info.
-******************************************************************************/
+/*
+ * SPDX-FileCopyrightText: All Contributors to the PyTango project
+ *
+ * SPDX-License-Identifier: LGPL-3.0-or-later
+ */
 
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
@@ -21,6 +16,11 @@ namespace PyAttrConfEventData
 static boost::shared_ptr<Tango::AttrConfEventData> makeAttrConfEventData()
 {
     Tango::AttrConfEventData *result = new Tango::AttrConfEventData;
+
+    // workaround https://gitlab.com/tango-controls/cppTango/-/issues/1383
+    result->attr_conf = nullptr;
+    result->device = nullptr;
+
     return boost::shared_ptr<Tango::AttrConfEventData>(result);
 }
 
