@@ -1,13 +1,8 @@
-/******************************************************************************
-  This file is part of PyTango (http://pytango.rtfd.io)
-
-  Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-  Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-
-  Distributed under the terms of the GNU Lesser General Public License,
-  either version 3 of the License, or (at your option) any later version.
-  See LICENSE.txt for more info.
-******************************************************************************/
+/*
+ * SPDX-FileCopyrightText: All Contributors to the PyTango project
+ *
+ * SPDX-License-Identifier: LGPL-3.0-or-later
+ */
 
 #include "precompiled_header.hpp"
 #include "defs.h"
@@ -42,6 +37,7 @@ void export_pipe_info();
 
 void export_dev_error();
 void export_time_val();
+void export_coverage_helper();
 
 //
 // Necessary equality operators for having vectors exported to python
@@ -415,4 +411,6 @@ void export_base_types()
     bopy::def("raise_asynch_exception", &raise_asynch_exception);
 
     bopy::def("_get_tango_lib_release", &Tango::_convert_tango_lib_release);
+
+    export_coverage_helper();
 }
