@@ -1,13 +1,8 @@
-/******************************************************************************
-  This file is part of PyTango (http://pytango.rtfd.io)
-
-  Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-  Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-
-  Distributed under the terms of the GNU Lesser General Public License,
-  either version 3 of the License, or (at your option) any later version.
-  See LICENSE.txt for more info.
-******************************************************************************/
+/*
+ * SPDX-FileCopyrightText: All Contributors to the PyTango project
+ *
+ * SPDX-License-Identifier: LGPL-3.0-or-later
+ */
 
 #include "precompiled_header.hpp"
 #include "pytgutils.h"
@@ -163,16 +158,7 @@ static void _run_virtual_once(PyCallBackAutoDie *_self, OriginalT *ev, const cha
 
         _self->get_override(virt_fn_name)(py_value);
     }
-    catch(bopy::error_already_set &eas)
-    {
-        _self->unset_autokill_references();
-        handle_python_exception(eas);
-    }
-    catch(...)
-    {
-        _self->unset_autokill_references();
-        throw;
-    }
+    SAFE_CATCH_INFORM(virt_fn_name)
     _self->unset_autokill_references();
 }
 
