@@ -1,13 +1,8 @@
-/******************************************************************************
-  This file is part of PyTango (http://pytango.rtfd.io)
-
-  Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-  Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-
-  Distributed under the terms of the GNU Lesser General Public License,
-  either version 3 of the License, or (at your option) any later version.
-  See LICENSE.txt for more info.
-******************************************************************************/
+/*
+ * SPDX-FileCopyrightText: All Contributors to the PyTango project
+ *
+ * SPDX-License-Identifier: LGPL-3.0-or-later
+ */
 
 #include "precompiled_header.hpp"
 #include "device_attribute.h"
@@ -795,7 +790,7 @@ void export_device_proxy()
         // pipe methods
         //
 
-        .def("get_pipe_list",
+        .def("_get_pipe_list",
              &Tango::DeviceProxy::get_pipe_list,
              (arg_("self")),
              bopy::return_value_policy<bopy::manage_new_object>())
