@@ -1,13 +1,8 @@
-/******************************************************************************
-  This file is part of PyTango (http://pytango.rtfd.io)
-
-  Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-  Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-
-  Distributed under the terms of the GNU Lesser General Public License,
-  either version 3 of the License, or (at your option) any later version.
-  See LICENSE.txt for more info.
-******************************************************************************/
+/*
+ * SPDX-FileCopyrightText: All Contributors to the PyTango project
+ *
+ * SPDX-License-Identifier: LGPL-3.0-or-later
+ */
 
 #include "precompiled_header.hpp"
 #include "pytgutils.h"
@@ -451,7 +446,7 @@ void export_exceptions()
         .def("re_throw_exception", &PyExcept::re_throw_exception)
         .def("re_throw_exception", &PyExcept::re_throw_exception_severity)
         .def("print_exception", &PyExcept::print_exception)
-        .def("print_error_stack", &Tango::Except::print_error_stack)
+        .def("print_error_stack", (void (*)(const Tango::DevErrorList &)) & Tango::Except::print_error_stack)
         .def("compare_exception", (bool (*)(const Tango::DevFailed &, const Tango::DevFailed &)) compare_exception_)
         .def("to_dev_failed", &to_dev_failed, to_dev_failed_overloads())
         .def("throw_python_exception", &throw_python_generic_exception, throw_python_generic_exception_overloads())
