@@ -1,17 +1,13 @@
-/******************************************************************************
-  This file is part of PyTango (http://pytango.rtfd.io)
-
-  Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-  Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-
-  Distributed under the terms of the GNU Lesser General Public License,
-  either version 3 of the License, or (at your option) any later version.
-  See LICENSE.txt for more info.
-******************************************************************************/
+/*
+ * SPDX-FileCopyrightText: All Contributors to the PyTango project
+ *
+ * SPDX-License-Identifier: LGPL-3.0-or-later
+ */
 
 #include "precompiled_header.hpp"
 #include "defs.h"
 #include "pytgutils.h"
+#include "server/device_class.h"
 
 namespace PyTango
 {
@@ -31,7 +27,7 @@ class AutoTangoMonitor
         dev = dev_arg;
     }
 
-    AutoTangoMonitor(Tango::DeviceClass *klass_arg) :
+    AutoTangoMonitor(CppDeviceClass *klass_arg) :
         mon(),
         dev(),
         klass()
@@ -141,7 +137,7 @@ class AutoTangoAllowThreads
     }
 
   private:
-    Tango::TangoMonitor *mon;
+    Tango::TangoMonitor *mon{nullptr};
     int count;
     omni_thread::ensure_self auto_self;
 };
@@ -151,7 +147,7 @@ class AutoTangoAllowThreads
 void export_auto_tango_monitor()
 {
     bopy::class_<PyTango::AutoTangoMonitor, boost::noncopyable>("AutoTangoMonitor", bopy::init<Tango::DeviceImpl *>())
-        .def(bopy::init<Tango::DeviceClass *>())
+        .def(bopy::init<CppDeviceClass *>())
         .def("_acquire", &PyTango::AutoTangoMonitor::acquire)
         .def("_release", &PyTango::AutoTangoMonitor::release);
 
