@@ -1,13 +1,5 @@
-# ------------------------------------------------------------------------------
-# This file is part of PyTango (http://pytango.rtfd.io)
-#
-# Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-# Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-#
-# Distributed under the terms of the GNU Lesser General Public License,
-# either version 3 of the License, or (at your option) any later version.
-# See LICENSE.txt for more info.
-# ------------------------------------------------------------------------------
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
 """
 This is an internal PyTango module.
@@ -19,12 +11,7 @@ __docformat__ = "restructuredtext"
 
 from tango._tango import ApiUtil
 
-from tango.utils import document_method, document_static_method, _get_env_var
-
-
-def __init_api_util():
-    if not hasattr(ApiUtil, "get_env_var"):
-        ApiUtil.get_env_var = staticmethod(_get_env_var)
+from tango.utils import document_method, document_static_method
 
 
 def __doc_api_util():
@@ -188,6 +175,5 @@ def __doc_api_util():
 
 
 def api_util_init(doc=True):
-    __init_api_util()
     if doc:
         __doc_api_util()
