@@ -1,14 +1,5 @@
-# ------------------------------------------------------------------------------
-# This file is part of PyTango (http://pytango.rtfd.io)
-#
-# Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-# Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-#
-# Distributed under the terms of the GNU Lesser General Public License,
-# either version 3 of the License, or (at your option) any later version.
-# See LICENSE.txt for more info.
-# ------------------------------------------------------------------------------
-
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 """
 This is an internal PyTango module. It completes the binding of
 :class:`tango.AttributeProxy`.
@@ -472,7 +463,9 @@ def __init_AttributeProxy(doc=True):
     # Asynchronous methods
     AttributeProxy.read_asynch = _method_dev_and_name("read_attribute_asynch", doc=doc)
     AttributeProxy.read_reply = _method_device("read_attribute_reply", doc=doc)
-    AttributeProxy.write_asynch = _method_device("write_attribute_asynch", doc=doc)
+    AttributeProxy.write_asynch = _method_dev_and_name(
+        "write_attribute_asynch", doc=doc
+    )
     AttributeProxy.write_reply = _method_device("write_attribute_reply", doc=doc)
 
     # Event methods
