@@ -1,13 +1,5 @@
-# ------------------------------------------------------------------------------
-# This file is part of PyTango (http://pytango.rtfd.io)
-#
-# Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-# Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-#
-# Distributed under the terms of the GNU Lesser General Public License,
-# either version 3 of the License, or (at your option) any later version.
-# See LICENSE.txt for more info.
-# ------------------------------------------------------------------------------
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
 """
 This is an internal PyTango module.
@@ -24,14 +16,11 @@ from tango._tango import (
     Connection,
     DeviceData,
     __CallBackAutoDie,
-    CmdArgType,
-    DeviceProxy,
-    Database,
     ExtractAs,
 )
 from tango.utils import document_method as __document_method
 from tango.utils import document_static_method as __document_static_method
-from tango.utils import _trace_client
+from tango.utils import _trace_client, _get_command_inout_param
 from tango.green import green
 
 
@@ -48,46 +37,6 @@ def __CallBackAutoDie__cmd_ended_aux(self, fn):
     return __new_fn
 
 
-def __get_command_inout_param(self, cmd_name, cmd_param=None):
-    if cmd_param is None:
-        return DeviceData()
-
-    if isinstance(cmd_param, DeviceData):
-        return cmd_param
-
-    if isinstance(self, DeviceProxy):
-        # This is not part of 'Connection' interface, but
-        # DeviceProxy only.
-        info = self.command_query(cmd_name)
-        param = DeviceData()
-        try:
-            param.insert(info.in_type, cmd_param)
-        except TypeError as err:
-            raise TypeError(
-                f"Invalid input argument for command {cmd_name}: "
-                f"{cmd_param!r} cannot be converted to type {info.in_type}"
-            ) from err
-        return param
-    elif isinstance(self, Database):
-        # I just try to guess types DevString and DevVarStringArray
-        # as they are used for Database
-        param = DeviceData()
-        if isinstance(cmd_param, str):
-            param.insert(CmdArgType.DevString, cmd_param)
-            return param
-        elif isinstance(cmd_param, collections.abc.Sequence) and all(
-            [isinstance(x, str) for x in cmd_param]
-        ):
-            param.insert(CmdArgType.DevVarStringArray, cmd_param)
-            return param
-        else:
-            raise TypeError(
-                "command_inout() parameter must be a DeviceData object or a string or a sequence of strings"
-            )
-    else:
-        raise TypeError("command_inout() parameter must be a DeviceData object.")
-
-
 def __Connection__command_inout(self, name, *args, **kwds):
     """
     command_inout( self, cmd_name, cmd_param=None, green_mode=None, wait=True, timeout=None) -> any
@@ -158,7 +107,7 @@ def __Connection__command_inout_raw(self, cmd_name, cmd_param=None):
         TypeError's for invalid command input arguments are now more detailed.
         For commands with a DEV_STRING input argument, invalid data will now raise TypeError instead of SystemError.
     """
-    param = __get_command_inout_param(self, cmd_name, cmd_param)
+    param = _get_command_inout_param(self, cmd_name, cmd_param)
     return self.__command_inout(cmd_name, param)
 
 
@@ -211,6 +160,13 @@ def __Connection__command_inout_asynch(self, cmd_name, *args):
         need to change the global TANGO model to PUSH_CALLBACK.
         You can do this with the :meth:`tango.ApiUtil.set_asynch_cb_sub_model`
 
+    .. important::
+        Multiple asynchronous calls are not guaranteed to be executed by the device
+        server in the same order they are invoked by the client.  E.g., a call
+        to ``command_inout_asynch("A")`` followed immediately with a call to
+        ``command_inout_asynch("B")`` could result in the device invoking
+        command ``B`` before command ``A``.
+
     .. versionchanged:: 10.0.0
         TypeError's for invalid command input arguments are now more detailed.
         For commands with a DEV_STRING input argument, invalid data will now raise TypeError instead of SystemError.
@@ -225,15 +181,15 @@ def __Connection__command_inout_asynch(self, cmd_name, *args):
         ):  # command_inout_asynch(lambda)
             cb = __CallBackAutoDie()
             cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(self, args[0])
-            argin = __get_command_inout_param(self, cmd_name)
+            argin = _get_command_inout_param(self, cmd_name)
             return self.__command_inout_asynch_cb(cmd_name, argin, cb)
         elif hasattr(args[0], "cmd_ended"):  # command_inout_asynch(Cbclass)
             cb = __CallBackAutoDie()
             cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(self, args[0].cmd_ended)
-            argin = __get_command_inout_param(self, cmd_name)
+            argin = _get_command_inout_param(self, cmd_name)
             return self.__command_inout_asynch_cb(cmd_name, argin, cb)
         else:  # command_inout_asynch(value)
-            argin = __get_command_inout_param(self, cmd_name, args[0])
+            argin = _get_command_inout_param(self, cmd_name, args[0])
             forget = False
             return self.__command_inout_asynch_id(cmd_name, argin, forget)
     elif len(args) == 2:
@@ -242,15 +198,15 @@ def __Connection__command_inout_asynch(self, cmd_name, *args):
         ):  # command_inout_asynch( value, lambda)
             cb = __CallBackAutoDie()
             cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(self, args[1])
-            argin = __get_command_inout_param(self, cmd_name, args[0])
+            argin = _get_command_inout_param(self, cmd_name, args[0])
             return self.__command_inout_asynch_cb(cmd_name, argin, cb)
         elif hasattr(args[1], "cmd_ended"):  # command_inout_asynch(value, cbClass)
             cb = __CallBackAutoDie()
             cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(self, args[1].cmd_ended)
-            argin = __get_command_inout_param(self, cmd_name, args[0])
+            argin = _get_command_inout_param(self, cmd_name, args[0])
             return self.__command_inout_asynch_cb(cmd_name, argin, cb)
         else:  # command_inout_asynch(value, forget)
-            argin = __get_command_inout_param(self, cmd_name, args[0])
+            argin = _get_command_inout_param(self, cmd_name, args[0])
             forget = bool(args[1])
             return self.__command_inout_asynch_id(cmd_name, argin, forget)
     else:
