@@ -1,13 +1,5 @@
-# ------------------------------------------------------------------------------
-# This file is part of PyTango (http://pytango.rtfd.io)
-#
-# Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-# Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-#
-# Distributed under the terms of the GNU Lesser General Public License,
-# either version 3 of the License, or (at your option) any later version.
-# See LICENSE.txt for more info.
-# ------------------------------------------------------------------------------
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
 """
 This is an internal PyTango module.
@@ -244,7 +236,7 @@ def __EncodedAttribute_encode_gray16(self, gray16, width=0, height=0):
                 "bytearray) inside a sequence"
             )
         width = len(row0)
-        if is_pure_str(row0) or type(row0) == bytearray:
+        if is_pure_str(row0) or type(row0) is bytearray:
             width /= 2
 
     self._encode_gray16(gray16, width, height)
@@ -384,7 +376,7 @@ def __EncodedAttribute_generic_encode_rgb24(
                 "bytearray) inside a sequence"
             )
         width = len(row0)
-        if is_pure_str(row0) or type(row0) == bytearray:
+        if is_pure_str(row0) or type(row0) is bytearray:
             width /= 3
     if format == _ImageFormat.RawImage:
         self._encode_rgb24(rgb24, width, height)
@@ -475,7 +467,7 @@ def __EncodedAttribute_encode_jpeg_rgb32(self, rgb32, width=0, height=0, quality
                 "bytearray) inside a sequence"
             )
         width = len(row0)
-        if is_pure_str(row0) or type(row0) == bytearray:
+        if is_pure_str(row0) or type(row0) is bytearray:
             width /= 4
 
     self._encode_jpeg_rgb32(rgb32, width, height, quality)
