@@ -1,13 +1,5 @@
-# ------------------------------------------------------------------------------
-# This file is part of PyTango (http://pytango.rtfd.io)
-#
-# Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-# Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-#
-# Distributed under the terms of the GNU Lesser General Public License,
-# either version 3 of the License, or (at your option) any later version.
-# See LICENSE.txt for more info.
-# ------------------------------------------------------------------------------
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
 """
 This is an internal PyTango module.
@@ -20,6 +12,7 @@ __docformat__ = "restructuredtext"
 import collections.abc
 
 from tango._tango import __Group as _RealGroup
+from tango.utils import _get_command_inout_param
 from tango.utils import seq_2_StdStringVector, is_non_str_seq, is_pure_str
 from tango.utils import document_method as __document_method
 from tango.utils import _get_device_fqtrl_if_necessary
@@ -136,14 +129,23 @@ class Group:
 
     @_trace_client
     def command_inout(self, cmd_name, param=None, forward=True):
-        if param is None:
-            idx = self.command_inout_asynch(cmd_name, forget=False, forward=forward)
-        else:
-            idx = self.command_inout_asynch(
-                cmd_name, param, forget=False, forward=forward
-            )
+        idx = self.command_inout_asynch(cmd_name, param, forward)
         return self.command_inout_reply(idx)
 
+    @_trace_client
+    def command_inout_asynch(self, cmd_name, param=None, forward=True):
+        if param is None:
+            idx = self.__group.command_inout_asynch(
+                cmd_name, forget=False, forward=forward
+            )
+        else:
+            arg_in = _get_command_inout_param(self.__group, cmd_name, param)
+            idx = self.__group.command_inout_asynch(
+                cmd_name, arg_in, forget=False, forward=forward
+            )
+
+        return idx
+
     @_trace_client
     def read_attribute(self, attr_name, forward=True):
         idx = self.__group.read_attribute_asynch(attr_name, forward)
@@ -165,7 +167,7 @@ class Group:
 def __init_proxy_Group():
     proxy_methods = [
         # 'add',  # Needs to be adapted
-        "command_inout_asynch",
+        # "command_inout_asynch",  # Needs to be adapted
         "command_inout_reply",
         "contains",
         "disable",
