@@ -1,13 +1,5 @@
-# ------------------------------------------------------------------------------
-# This file is part of PyTango (http://pytango.rtfd.io)
-#
-# Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-# Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-#
-# Distributed under the terms of the GNU Lesser General Public License,
-# either version 3 of the License, or (at your option) any later version.
-# See LICENSE.txt for more info.
-# ------------------------------------------------------------------------------
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
 """
 This is an internal PyTango module.
@@ -402,7 +394,7 @@ def parse_args(args):
 
     # we add back only exist options
     for key, value in parsed_args.__dict__.items():
-        if type(value) == bool:
+        if type(value) is bool:
             if value:
                 args += [f"-{key:s}"]
         elif value is not None:
@@ -503,7 +495,7 @@ def __doc_Util():
     class and its constructor is not public. Example::
 
         util = tango.Util.instance()
-            print(util.get_host_name())
+        print(util.get_host_name())
     """
 
     def document_method(method_name, desc, append=True):
