@@ -1,13 +1,5 @@
-# ------------------------------------------------------------------------------
-# This file is part of PyTango (http://pytango.rtfd.io)
-#
-# Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-# Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-#
-# Distributed under the terms of the GNU Lesser General Public License,
-# either version 3 of the License, or (at your option) any later version.
-# See LICENSE.txt for more info.
-# ------------------------------------------------------------------------------
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
 """Server helper classes for writing Tango device servers."""
 
@@ -22,6 +14,11 @@ import warnings
 from typing import Union, ClassVar
 from inspect import getfullargspec
 
+try:
+    from warnings import deprecated
+except ImportError:
+    from typing_extensions import deprecated
+
 from tango._tango import AttrDataFormat, AttrWriteType, PipeWriteType, DevState
 from tango._tango import DevFailed, GreenMode, SerialModel
 
@@ -536,7 +533,7 @@ def __warn_if_standard_device_methods_should_be_coroutine(klass):
     # get base device class:
     if isinstance(worker, AsyncioExecutor):
         for parent in klass.__bases__:
-            if type(parent) == DeviceMeta:
+            if type(parent) is DeviceMeta:
                 for method in (
                     "init_device",
                     "delete_device",
@@ -930,7 +927,7 @@ class DeviceMeta(type(LatestDeviceImpl)):
         # Attribute dictionary
         dct = {}
         # Filter object from bases
-        bases = tuple(base for base in bases if base != object)
+        bases = tuple(base for base in bases if base is not object)
         # Set tango objects as attributes
         for base in reversed(bases):
             for key, value in base.__dict__.items():
@@ -999,14 +996,38 @@ class BaseDevice(LatestDeviceImpl):
 
     def init_device(self):
         """
-        Tango init_device method. Default implementation calls
-        :meth:`get_device_properties`"""
+        Code to handle device initialisation.
+
+        This method is called automatically when the device starts,
+        but before it is available to clients (i.e., before it is "exported").
+        It also gets called if the device is re-initialised by a call to the
+        ``Init`` command (after :meth:`~tango.server.Device.delete_device`).
+
+        Default implementation calls :meth:`get_device_properties`
+
+        If overwriting this method, it is important to call the super class
+        method first:
+
+        - For synchronous devices: ``super().init_device()``
+        - For asyncio green mode devices: ``await super().init_device()``
+        """
         self.get_device_properties()
 
     def delete_device(self):
-        pass
+        """
+        Code to handle device clean-up.
 
-    delete_device.__doc__ = LatestDeviceImpl.delete_device.__doc__
+        This method is called automatically when the device is shut down gracefully.
+        It also gets called if the device is re-initialised by a call to the ``Init``
+        command (before a new call to :meth:`~tango.server.Device.init_device`).
+
+        If overwriting this method, it is important to call the super class
+        method last:
+
+        - For synchronous devices: ``super().delete_device()``
+        - For asyncio green mode devices: ``await super().delete_device()``
+        """
+        pass
 
     def read_attr_hardware(self, attr_list):
         return LatestDeviceImpl.read_attr_hardware(self, attr_list)
@@ -1175,16 +1196,16 @@ class attribute(AttrData):
     memorized              :obj:`bool`                      False                                   attribute must be memorized (only applicable to scalar, writeable attributes).  If True, the latest write value, i.e., set point, is stored in the Tango database - see also ``hw_memorized`` parameter.  Corresponds to low-level :meth:`tango.Attr.set_memorized`.
     hw_memorized           :obj:`bool`                      False                                   memorized value will be restored by automatically calling attribute write method at startup, and after each ``Init`` command call (only applies if ``memorized`` is set to True).  Corresponds to low-level :meth:`tango.Attr.set_memorized_init`
     access                 :obj:`~tango.AttrWriteType`      :obj:`~tango.AttrWriteType.READ`        read only/ read write / write only access
-    fget (or fread)        :obj:`str` or :obj:`callable`    'read_<attr_name>'                      read method name or method object
-    fset (or fwrite)       :obj:`str` or :obj:`callable`    'write_<attr_name>'                     write method name or method object
-    fisallowed             :obj:`str` or :obj:`callable`    'is_<attr_name>_allowed'                is allowed method name or method object
-    label                  :obj:`str`                       '<attr_name>'                           attribute label
+    fget (or fread)        :obj:`str` or :obj:`callable`    ``read_<attr_name>``                    read method name or method object
+    fset (or fwrite)       :obj:`str` or :obj:`callable`    ``write_<attr_name>``                   write method name or method object
+    fisallowed             :obj:`str` or :obj:`callable`    ``is_<attr_name>_allowed``              is allowed method name or method object
+    label                  :obj:`str`                       ``<attr_name>``                         attribute label
     enum_labels            sequence                         None                                    the list of enumeration labels (enum data type)
-    doc (or description)   :obj:`str`                       ''                                      attribute description
-    unit                   :obj:`str`                       ''                                      physical units the attribute value is in
-    standard_unit          :obj:`str`                       ''                                      physical standard unit
-    display_unit           :obj:`str`                       ''                                      physical display unit (hint for clients)
-    format                 :obj:`str`                       '6.2f'                                  attribute representation format
+    doc (or description)   :obj:`str`                       ``""``                                  attribute description
+    unit                   :obj:`str`                       ``""``                                  physical units the attribute value is in
+    standard_unit          :obj:`str`                       ``""``                                  physical standard unit
+    display_unit           :obj:`str`                       ``""``                                  physical display unit (hint for clients)
+    format                 :obj:`str`                       ``"6.2f"``                              attribute representation format
     min_value              :obj:`str`                       None                                    minimum allowed value
     max_value              :obj:`str`                       None                                    maximum allowed value
     min_alarm              :obj:`str`                       None                                    minimum value to trigger attribute alarm
@@ -1200,9 +1221,9 @@ class attribute(AttrData):
     archive_rel_change     :obj:`str`                       None
     archive_period         :obj:`str`                       None
     green_mode             :obj:`bool`                      True                                    Default green mode for read/write/isallowed functions. If True: run with green mode executor, if False: run directly
-    read_green_mode        :obj:`bool`                      'green_mode' value                      green mode for read function. If True: run with green mode executor, if False: run directly
-    write_green_mode       :obj:`bool`                      'green_mode' value                      green mode for write function. If True: run with green mode executor, if False: run directly
-    isallowed_green_mode   :obj:`bool`                      'green_mode' value                      green mode for is allowed function. If True: run with green mode executor, if False: run directly
+    read_green_mode        :obj:`bool`                      ``green_mode`` value                    green mode for read function. If True: run with green mode executor, if False: run directly
+    write_green_mode       :obj:`bool`                      ``green_mode`` value                    green mode for write function. If True: run with green mode executor, if False: run directly
+    isallowed_green_mode   :obj:`bool`                      ``green_mode`` value                    green mode for is allowed function. If True: run with green mode executor, if False: run directly
     forwarded              :obj:`bool`                      False                                   the attribute should be forwarded if True
     ===================== ================================ ======================================= =======================================================================================
 
@@ -1384,6 +1405,7 @@ class attribute(AttrData):
         return type(self)(fget=fget, **self._kwargs)
 
 
+@deprecated("pipe - scheduled for removal in PyTango 10.1.0")
 class pipe(PipeData):
     '''
     Declares a new tango pipe in a :class:`Device`. To be used
@@ -1424,15 +1446,15 @@ class pipe(PipeData):
     name                   :obj:`str`                       class member name                       alternative pipe name
     display_level          :obj:`~tango.DispLevel`          :obj:`~tango.DisLevel.OPERATOR`         display level
     access                 :obj:`~tango.PipeWriteType`      :obj:`~tango.PipeWriteType.READ`        read only/ read write access
-    fget (or fread)        :obj:`str` or :obj:`callable`    'read_<pipe_name>'                      read method name or method object
-    fset (or fwrite)       :obj:`str` or :obj:`callable`    'write_<pipe_name>'                     write method name or method object
-    fisallowed             :obj:`str` or :obj:`callable`    'is_<pipe_name>_allowed'                is allowed method name or method object
-    label                  :obj:`str`                       '<pipe_name>'                           pipe label
-    doc (or description)   :obj:`str`                       ''                                      pipe description
+    fget (or fread)        :obj:`str` or :obj:`callable`    ``read_<pipe_name>``                    read method name or method object
+    fset (or fwrite)       :obj:`str` or :obj:`callable`    ``write_<pipe_name>``                   write method name or method object
+    fisallowed             :obj:`str` or :obj:`callable`    ``is_<pipe_name>_allowed``              is allowed method name or method object
+    label                  :obj:`str`                       ``<pipe_name>``                         pipe label
+    doc (or description)   :obj:`str`                       ``""``                                  pipe description
     green_mode             :obj:`bool`                      True                                    Default green mode for read/write/isallowed functions. If True: run with green mode executor, if False: run directly
-    read_green_mode        :obj:`bool`                      'green_mode' value                      green mode for read function. If True: run with green mode executor, if False: run directly
-    write_green_mode       :obj:`bool`                      'green_mode' value                      green mode for write function. If True: run with green mode executor, if False: run directly
-    isallowed_green_mode   :obj:`bool`                      'green_mode' value                      green mode for is allowed function. If True: run with green mode executor, if False: run directly
+    read_green_mode        :obj:`bool`                      ``green_mode`` value                    green mode for read function. If True: run with green mode executor, if False: run directly
+    write_green_mode       :obj:`bool`                      ``green_mode`` value                    green mode for write function. If True: run with green mode executor, if False: run directly
+    isallowed_green_mode   :obj:`bool`                      ``green_mode`` value                    green mode for is allowed function. If True: run with green mode executor, if False: run directly
     ===================== ================================ ======================================= =======================================================================================
 
     The same example with a read-write ROI, a customized label and description::
@@ -1477,6 +1499,9 @@ class pipe(PipeData):
 
     .. versionadded:: 9.4.0
         added isallowed_green_mode option
+
+    .. deprecated:: 10.0.1
+        Pipes scheduled for removal from PyTango in version 10.1.0
     '''
 
     def __init__(self, fget=None, **kwargs):
