@@ -1,13 +1,5 @@
-# ------------------------------------------------------------------------------
-# This file is part of PyTango (http://pytango.rtfd.io)
-#
-# Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-# Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-#
-# Distributed under the terms of the GNU Lesser General Public License,
-# either version 3 of the License, or (at your option) any later version.
-# See LICENSE.txt for more info.
-# ------------------------------------------------------------------------------
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
 """Server for tango objects."""
 
@@ -20,6 +12,11 @@ import inspect
 import functools
 import numpy
 
+try:
+    from warnings import deprecated
+except ImportError:
+    from typing_extensions import deprecated
+
 from tango.codec import loads, dumps
 from tango.attr_data import AttrData
 from tango.utils import TO_TANGO_TYPE
@@ -71,6 +68,9 @@ def __to_tango_type_fmt(value):
     return dtype, dfmt, max_dim_x, max_dim_y
 
 
+@deprecated(
+    "create_tango_class function was an experimental API - scheduled for removal in PyTango 11.0.0"
+)
 def create_tango_class(server, obj, tango_class_name=None, member_filter=None):
     slog = server.server_instance.replace("/", ".")
     log = logging.getLogger("tango.Server." + slog)
@@ -208,6 +208,9 @@ def create_tango_class(server, obj, tango_class_name=None, member_filter=None):
     return DeviceDispatcher
 
 
+@deprecated(
+    "Server class was an experimental API - scheduled for removal in PyTango 11.0.0"
+)
 class Server:
     """
     Server helper
