@@ -1,5 +1,7 @@
-"""Provide a context to run a device without a database."""
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
+"""Provide a context to run a device without a database."""
 
 # Imports
 import os
@@ -367,8 +369,8 @@ class MultiDeviceTestContext:
       True if the device server should be launched in a new process, otherwise
       use a new thread.  Note:  if the context will be used mutiple times, it
       may seg fault if the thread mode is chosen.
-      See the :ref:`issues <testing_approaches_issues>` and
-      :ref:`process kwarg <testing_approaches_process_kwarg>` discussion in the docs.
+      See the :ref:`issues <testing-approaches-issues>` and
+      :ref:`process kwarg <testing-approaches-process-kwarg>` discussion in the docs.
       Optional.  Default is thread.
     :type process:
       :py:obj:`bool`
