@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
+
 """Test utilities"""
 
 import enum
@@ -22,6 +25,7 @@ from tango import (
     DevFailed,
     DevVarLongStringArray,
     DevVarDoubleStringArray,
+    SerialModel,
 )
 from tango.server import Device
 from tango.test_context import MultiDeviceTestContext, DeviceTestContext
@@ -139,14 +143,14 @@ GENERAL_TYPED_VALUES = {
     bool: (False, True, True, False),
     (int,): (
         np.array([1, 2]),
-        [1, 2, 3],
+        (1, 2, 3),
         [9, 8, 7],
         [-65535, 2224],
         [0, 0],
     ),
     (float,): (
         np.array([0.1, 0.2]),
-        [0.1, 0.2, 0.3],
+        (0.1, 0.2, 0.3),
         [0.9, 0.8, 0.7],
         [-6.3232e-3],
         [0.0, 12.56e12],
@@ -175,12 +179,12 @@ COMMAND_TYPED_VALUES = {
 IMAGE_TYPED_VALUES = {
     ((int,),): (
         np.vstack((np.array([1, 2]), np.array([3, 4]))),
-        [[1, 2, 3], [4, 5, 6]],
+        ((1, 2, 3), (4, 5, 6)),
         [[-65535, 2224], [-65535, 2224]],
     ),
     ((float,),): (
         np.vstack((np.array([0.1, 0.2]), np.array([0.3, 0.4]))),
-        [[0.1, 0.2, 0.3], [0.9, 0.8, 0.7]],
+        ((0.1, 0.2, 0.3), (0.9, 0.8, 0.7)),
         [[-6.3232e-3, 0.0], [0.0, 12.56e12]],
     ),
     ((str,),): (
@@ -492,6 +496,9 @@ if pytest:
                 assert k in b
                 assert_close(v, b[k])
             return
+        elif isinstance(a, (np.bool_, bool)) or isinstance(b, (np.bool_, bool)):
+            assert a == b
+            return
         try:
             assert a == pytest.approx(b)
         except (ValueError, TypeError):
@@ -528,9 +535,9 @@ if pytest:
             return np.array(value, dtype=FROM_TANGO_TO_NUMPY_TYPE[attr_type])
         elif expected_type in [bytes, bytearray, str]:
             value = np.array(value, dtype=FROM_TANGO_TO_NUMPY_TYPE[attr_type]).tobytes()
-            if expected_type == bytearray:
+            if expected_type is bytearray:
                 return bytearray(value)
-            elif expected_type == str:
+            elif expected_type is str:
                 return "".join([chr(b) for b in value])
             return value
         else:
@@ -645,3 +652,14 @@ if pytest:
     )
     def attr_data_format(request):
         return request.param
+
+    @pytest.fixture(
+        params=[
+            SerialModel.BY_DEVICE,
+            SerialModel.BY_CLASS,
+            SerialModel.BY_PROCESS,
+            SerialModel.NO_SYNC,
+        ]
+    )
+    def server_serial_model(request):
+        return request.param
