@@ -1,13 +1,5 @@
-# ------------------------------------------------------------------------------
-# This file is part of PyTango (http://pytango.rtfd.io)
-#
-# Copyright 2006-2012 CELLS / ALBA Synchrotron, Bellaterra, Spain
-# Copyright 2013-2014 European Synchrotron Radiation Facility, Grenoble, France
-#
-# Distributed under the terms of the GNU Lesser General Public License,
-# either version 3 of the License, or (at your option) any later version.
-# See LICENSE.txt for more info.
-# ------------------------------------------------------------------------------
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
 """
 This is an internal PyTango module.
@@ -60,10 +52,14 @@ from tango._tango import (
     EncodedAttribute,
     ApiUtil,
     EnsureOmniThread,
+    DeviceData,
+    DeviceDataList,
+    DeviceProxy,
+    __Group,
 )
 
 from tango import _tango
-from tango._tango import _telemetry
+from tango._tango import _telemetry, Except
 from tango.constants import (
     AlrmValueNotSpec,
     StatusNotSet,
@@ -122,6 +118,7 @@ __all__ = (
     "_telemetry_active",
     "_trace_client",
     "_DummyTracer",
+    "_get_command_inout_param",
 )
 
 __docformat__ = "restructuredtext"
@@ -575,7 +572,7 @@ def parse_type_hint(annotation, caller):
         n_elements = len(typing.get_args(dtype))
         if (
             n_elements in [2, 4]
-            and typing.get_args(dtype)[0] == str
+            and typing.get_args(dtype)[0] is str
             and typing.get_args(dtype)[1] in [bytes, bytearray]
         ):
             return "DevEncoded", dformat, max_x, max_y
@@ -593,7 +590,7 @@ def parse_type_hint(annotation, caller):
             return "DevVarDoubleStringArray", dformat, max_x, max_y
         if (
             n_elements == 3
-            and typing.get_args(dtype)[1] == float
+            and typing.get_args(dtype)[1] is float
             and typing.get_args(dtype)[2] == AttrQuality
         ):
             dtype = typing.get_args(dtype)[0]
@@ -1026,7 +1023,7 @@ def seq_2_StdDoubleVector(seq, vec=None):
     if not isinstance(vec, StdDoubleVector):
         raise TypeError("vec must be a tango.StdDoubleVector")
     for e in seq:
-        vec.append(str(e))
+        vec.append(float(e))
     return vec
 
 
@@ -2723,3 +2720,94 @@ class PyTangoThreadPoolExecutor(ThreadPoolExecutor):
 def _thread_pool_executor_worker(executor_reference, work_queue, initializer, initargs):
     with EnsureOmniThread():
         _worker(executor_reference, work_queue, initializer, initargs)
+
+
+def _get_command_inout_param(self, cmd_name, cmd_param=None):
+    if cmd_param is None:
+        return DeviceData()
+
+    if isinstance(cmd_param, DeviceData):
+        return cmd_param
+
+    if isinstance(self, DeviceProxy):
+        # This is not part of 'Connection' interface, but
+        # DeviceProxy only.
+        info = self.command_query(cmd_name)
+        param = DeviceData()
+        try:
+            param.insert(info.in_type, cmd_param)
+        except TypeError as err:
+            raise TypeError(
+                f"Invalid input argument for command {cmd_name}: "
+                f"{cmd_param!r} cannot be converted to type {info.in_type}"
+            ) from err
+        return param
+    elif isinstance(self, __Group):
+
+        if self.get_size() == 0:
+            return DeviceData()
+
+        if isinstance(cmd_param, DeviceDataList):
+            return cmd_param
+
+        last_cause = None
+        try:
+            types = set()
+            typ = None
+            for idx in range(1, self.get_size() + 1):
+                dev = self.get_device(idx)
+                try:
+                    typ = dev.command_query(cmd_name).in_type
+                    types.add(typ)
+                except DevFailed as df:
+                    last_cause = df
+            if not types:
+                if last_cause:
+                    Except.re_throw_exception(
+                        last_cause,
+                        "PyAPI_GroupCommandArgInTypeUnknown",
+                        "Cannot fetch at least one command type in group.",
+                        "Group.command_inout_asynch",
+                    )
+                else:
+                    Except.throw_exception(
+                        "PyAPI_GroupCommandArgInTypeUnknown",
+                        "Cannot fetch at least one command type in group. Unknown cause.",
+                        "Group.command_inout_asynch",
+                    )
+            elif len(types) > 1:
+                raise TypeError(
+                    "Cannot execute command with more than one type in group, types are:\n"
+                    f"{types}"
+                )
+        finally:
+            del last_cause
+
+        param = DeviceData()
+        try:
+            param.insert(typ, cmd_param)
+        except TypeError as err:
+            raise TypeError(
+                f"Invalid input argument for command {cmd_name}: "
+                f"{cmd_param!r} cannot be converted to type {typ}"
+            ) from err
+        return param
+
+    elif isinstance(self, Database):
+        # I just try to guess types DevString and DevVarStringArray
+        # as they are used for Database
+        param = DeviceData()
+        if isinstance(cmd_param, str):
+            param.insert(CmdArgType.DevString, cmd_param)
+            return param
+        elif isinstance(cmd_param, collections.abc.Sequence) and all(
+            [isinstance(x, str) for x in cmd_param]
+        ):
+            param.insert(CmdArgType.DevVarStringArray, cmd_param)
+            return param
+        else:
+            raise TypeError(
+                "command_inout() parameter must be a DeviceData object or a string or a sequence of strings"
+            )
+    else:
+        raise TypeError("command_inout() parameter must be a DeviceData object.")
