@@ -1,3 +1,5 @@
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 # Imports
 import asyncio
 import time
@@ -153,6 +155,7 @@ def test_async_attribute_with_callback(model):
     with DeviceTestContext(ServerTest) as proxy:
         # asynchronous write/read of multiple attributes
         proxy.write_attributes_asynch([("attr1", 123), ("attr2", 456)], write_callback)
+        time.sleep(A_BIT)
         proxy.read_attributes_asynch(["attr1", "attr2"], read_callback)
 
         if model == "poll":
@@ -370,9 +373,6 @@ def test_async_attribute_write_with_pushed_callback(attr, err):
         assert result.err == err
 
 
-@pytest.mark.skip(
-    reason="This test will fail, because exception in the callback is not handled by CppTango"
-)
 def test_async_exception_in_callback():
     api_util = ApiUtil.instance()
     api_util.set_asynch_cb_sub_model(cb_sub_model.PUSH_CALLBACK)
