@@ -1,3 +1,5 @@
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 # Imports
 
 import time
@@ -204,7 +206,7 @@ def assert_events_received(event_device, expected_res):
 
 def run_event_test(event_device, event_type, cb, expected_res):
     event_results.clear()
-    event_device.reset()
+    event_device.command_inout("reset", wait=True)
 
     eid_change = event_device.subscribe_event("attr", event_type, cb, wait=True)
 
