@@ -1,3 +1,5 @@
+# SPDX-FileCopyrightText: All Contributors to the PyTango project
+# SPDX-License-Identifier: LGPL-3.0-or-later
 import os
 import warnings
 
@@ -121,8 +123,7 @@ class Device3(Device):
 
 
 def test_no_warnings_in_test_context():
-    class TestDevice(Device):
-        ...
+    class TestDevice(Device): ...
 
     warnings.filterwarnings("error")
     with DeviceTestContext(TestDevice):
@@ -447,7 +448,7 @@ def test_green_modes_in_device_kwarg_and_global(
             with pytest.raises(exception_type, match=r"stuck at init"):
                 with DeviceTestContext(device_type, green_mode=green_mode, timeout=0.5):
                     pass
-        assert type(get_worker()) == executor_type
+        assert type(get_worker()) is executor_type
 
     finally:
         tango.set_green_mode(old_green_mode)
@@ -538,54 +539,6 @@ def test_single_short_name_attribute_proxy_access_without_tango_db():
         assert attr1.read().value == 100
 
 
-def test_multi_short_name_group_access_without_tango_db():
-    devices_info = (
-        {
-            "class": Device1,
-            "devices": [{"name": "test/device1/1"}, {"name": "test/device1/2"}],
-        },
-    )
-
-    with MultiDeviceTestContext(devices_info) as context:
-        group_singles = tango.Group("add-one-at-a-time")
-        group_singles.add("test/device1/1")
-        group_singles.add("test/device1/2")
-        group_multiples_list = tango.Group("add-multiple-via-list")
-        group_multiples_list.add(["test/device1/1", "test/device1/2"])
-        group_multiples_vector = tango.Group("add-multiple-via-std-vector")
-        vector = tango.StdStringVector()
-        vector.append("test/device1/1")
-        vector.append("test/device1/2")
-        group_multiples_vector.add(vector)
-        group_in_group = tango.Group("add-sub-group")
-        group_in_group.add(group_singles)
-
-        groups = [
-            group_singles,
-            group_multiples_list,
-            group_multiples_vector,
-            group_in_group,
-        ]
-
-        device1_fqdn = context.get_device_access("test/device1/1")
-        device2_fqdn = context.get_device_access("test/device1/2")
-        for group in groups:
-            assert device1_fqdn in group
-            assert device2_fqdn in group
-            reply = group.read_attribute("attr1")
-            assert reply[0].dev_name() == device1_fqdn
-            assert reply[1].dev_name() == device2_fqdn
-            assert not reply[0].has_failed()
-            assert not reply[1].has_failed()
-            assert reply[0].get_data().value == 100
-            assert reply[1].get_data().value == 100
-
-        # patterns are not supported via DeviceTestContext
-        with pytest.raises(tango.DevFailed):
-            group_multiples_pattern = tango.Group("add-multiple-via-pattern")
-            group_multiples_pattern.add("test/device1/*")
-
-
 def test_multi_short_name_access_fails_if_override_disabled():
     devices_info = ({"class": Device1, "devices": [{"name": "test/device1/a"}]},)
 
